#
# spec file for package cairomm
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cairomm
Version:        1.16.1
Release:        2.5
Summary:        C++ Interface for Cairo
License:        LGPL-2.1-or-later
Group:          System/GUI/GNOME
URL:            https://www.cairographics.org/
Source:         https://www.cairographics.org/releases/%{name}-%{version}.tar.xz

BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  meson
BuildRequires:  mm-common
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(cairo) >= 1.10.0
BuildRequires:  pkgconfig(sigc++-3.0) >= 2.5.1

%description
This package provides a C++ interface for Cairo.

%package -n libcairomm-1_16-1
Summary:        C++ interface for Cairo
Group:          System/Libraries

%description -n libcairomm-1_16-1
This package provides a C++ interface for Cairo.

%package devel
Summary:        Header files for the Cairo C++ interface
Group:          Development/Libraries/GNOME
Requires:       libcairomm-1_16-1 = %{version}

%description devel
This package contains the header files for developing
applications that want to make use of cairomm.

%package doc
Summary:        Documentation for the Cairo C++ interface
Group:          Documentation/HTML

%description doc
This package provides documentation for the Cairo C++ interface.

%prep
%autosetup -p1
# fix permissions
chmod 0644 AUTHORS ChangeLog NEWS README

%build
%meson \
	-Dbuild-documentation=true \
	%{nil}
%meson_build

%install
%meson_install

%post -n libcairomm-1_16-1 -p /sbin/ldconfig
%postun -n libcairomm-1_16-1 -p /sbin/ldconfig

%files -n libcairomm-1_16-1
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/*.so.*

%files devel
%{_libdir}/*.so
%dir %{_libdir}/cairomm-1.16/
%{_libdir}/cairomm-1.16/include
%{_libdir}/pkgconfig/*.pc
%{_includedir}/*

%files doc
%{_datadir}/devhelp/books/cairomm-1.16
%{_datadir}/doc/cairomm-1.16
# Avoid BuildRequires on devhelp
%dir %{_datadir}/devhelp
%dir %{_datadir}/devhelp/books

%changelog
* Mon Dec 19 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: there is no known consumer of the -32bit
  package.
* Wed Jun 30 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.16.1
  + Only build system related changes
* Mon Nov  2 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.16.0:
  + This is the first stable release in the cairomm-1.16 ABI
    series. It is parallel-installable with the cairomm-1.0 ABI.
  + Cairo:
  - Add Context::get_source_for_surface()
  - Fix a memory leak in RefPtr
  + Build:
  - Require C++17
  - Add NMake Makefiles. Remove the Visual Studio projects
  - Add support for building with Meson
  - Use __declspec(dllexport) when building cairomm on Visual
    Studio. Stop using gendef.exe
  - docs/reference/: Update for Doxygen >= 1.8.16
  + Tests:
  - Update the source code
  - Don't include deprecated Boost header files. Fix tests in
    Autotools builds
  + Documentation: README: Update with instructions for building
    cairomm.
- Add meson BuildRequires and macros following upstreams port.
- Add graphviz BuildRequires, needed now for building
  documentation.
* Thu Apr 18 2019 Jan Engelhardt <jengelh@inai.de>
- Description updates.
* Tue Apr 17 2018 dimstar@opensuse.org
- Export CXXFLAGS="-std=c++17" until upstream fixes this. Requires,
  as libsigc++-3.0 moved to C++17.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Sep  4 2017 luc14n0@linuxmail.org
- Update to version 1.15.5:
  + enums.h: Guard the FT-specific include and the enum with an
    ifdef (fdo#100894).
  + Build: configure.ac: Require C++14, because libsigc++-3.0 does
    (fdo#100884).
* Sat May 20 2017 zaitor@opensuse.org
- Update to version 1.15.4:
  + Use C++11 enum classes instead of old-style enums, and put some
    enums inside relevant class declarations:
  - Change Cairo::RegionOverlap enum to Cairo::Region::Overlap.
  - Change Cairo::PatternType enum to Cairo::Pattern::Type.
  - Change Cairo::FontWeight enum to Cairo::ToyFontFace::Weight.
  - Change Cairo::FontSlant enum to Cairo::ToyFontFace::Slant.
  - Change Cairo::SurfaceType enum to Cairo::Surface::Type.
  - Change Cairo::HintMetrics enum to
    Cairo::FontOptions::HintMetrics.
  - Change Cairo::HintStyle enum to
    Cairo::FontOptions::HintStyle.
  - Change Cairo::Filter enum to Cairo::SurfacePattern::Filter.
  - Change Cairo::Extend enum to Cairo::Pattern::Extend.
  - Change Cairo::Format enum to Cairo::Surface::Format.
  - Change Cairo::DeviceType enum to Cairo::Device::DeviceType.
  - Change Cairo::LineJoin enum to Cairo::Context::LineJoin.
  - Change Cairo::LineCap enum to Cairo::Context::LineCap.
  - Change Cairo::FillRule enum to Cairo::Context::FillRule.
  - Change Cairo::Operator enum to Cairo::Context::Operator.
  + Build: Win32 / Visual Studio builds:
  - Require Visual Studio 2017.
  - Remove leftovers from removing deprecated Win32::create().
- Stop using service for tarball, upstream releasing again.
- Following the above: Drop libtool BuildRequires, and stop passing
  NOCONFIGURE=1 ./autogen.sh.
* Fri Jan 20 2017 zaitor@opensuse.org
- Update to version 1.15.3:
  + RefPtr: This is now an alias for std::shared_ptr<>. These
    should be instatiated via Cairo::make_refptr_for_instance(),
    though that should never be necessary anyway outside of the
    cairomm implementation itself.
* Fri Dec  9 2016 zaitor@opensuse.org
- Update to version 1.15.2:
  + Remove deprecated API.
  + Remove old API that takes cairo_matrix_t*.
* Sat Dec  3 2016 dimstar@opensuse.org
- Update to version 1.15.1:
  + First release of the cairomm-1.16 API/ABI that installs in
    parallel with cairomm-1.0. This uses libsigc++-3.0 instead of
    libsigc++-2.0.
- Changes from version 1.13.1:
  + Added RecordingSurface, wrapping cairo_recording_surface
    (fdo#121359).
- Replace libsigc++2-devel BuildRequires with
  pkgconfig(sigc++-3.0), following upstream.
- Replace cairo-devel BuildRequires with pkgconfig(cairo): match
  what configure is looking for.
- Rename libcairomm-1_0-1 subpackage to libcairomm-1_16-1,
  following upstreams soname change to represent the new ABI/API.
- Add libtool, mm-common and xlstproc BuildRequires as well as call
  autogen.sh: required, as we have a non-bootstrapped git tarball.
- Drop legacy cairomm provides/obsolete from the library package:
  with the soname change this can't possibly still be a drop-in.
* Sun Nov 20 2016 zaitor@opensuse.org
- Update to version 1.12.2:
  + Remove new API that was not meant to be added in 1.12.1.
- Changes from version 1.12.1:
  + C++11:
  - Use nullptr instead of 0.
  - Use override keyword on destructors.
  - Make operator bool() explicit.
* Wed Jun  1 2016 jengelh@inai.de
- Remove unnecessary INSTALL file (resolves rpmlint warning)
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Wed Sep 30 2015 zaitor@opensuse.org
- Update to version 1.12.0:
  + Cairo::RefPtr: Add move constructors and move operator=().
  + MSVC build fixes.
* Sun Aug 16 2015 zaitor@opensuse.org
- Update to version 1.11.4:
  + Use (and require) C++11.
  + Add Script and ScriptSurface.
  + Context: get_surface_wrapper(): Handle
    CAIRO_SURFACE_TYPE_SCRIPT, returning a ScriptSurface.
  + Surface: get_device(): Handle CAIRO_SURFACE_TYPE_SCRIPT,
    returning a Script.
  + Wrap cairo script device and script surface APIs.
  + FtFontFace: Add get/set/unset_synthesize().
  + Update MSVC.Net 2010 project files.
* Fri May 15 2015 dimstar@opensuse.org
- Add baselibs.conf to source list.
* Mon Mar  3 2014 zaitor@opensuse.org
- Update to version 1.11.2:
  + Pattern: Add set_extend() and get_extend().
  + ScaledFont: Add the missing get_extents() method
    implementation.
  + Allow use from Objective-C instead of just allowing building.
  + Avoid dereferencing empty std::vector<>s.
  + Documentation improvements.
  + Fix linker problems in examples.
* Sat Sep 21 2013 dimstar@opensuse.org
- Change RPM Group of shared library package to System/Libraries.
* Thu Mar 21 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel building
- Add cairomm-devel to baselibs
* Fri May 27 2011 vuntz@opensuse.org
- Update to version 1.10.0:
  + Documentation: Context::arc(): Correct the documentation, as in
    the C documentation (fdo#31345).
* Fri Jan  7 2011 vuntz@opensuse.org
- Update to version 1.9.8:
  + Surface:
  - added create() for creating a sub-surface representing a
    rectangle on a target surface
  - PDF versioning API: get_versions(), restrict_to_version(),
    version_to_string()
  - add get_device()
  - add new surface type enum values
  + Device
  - add acquire() and release() functions
  - Add Device::Lock convenience class
  + Region
  - UNSTABLE API CHANGE: Fix do_union(), subtract(), intersect()
    to throw exceptions instead of returning error statuses to be
    consistent with the rest of the cairomm API
  - add xor() functions
  - add API for creating a region from a list of rectangles
  - implement copy()
  + Documentation:
  - Context::arc(): Fix fdo#31345 about bad math in arc()
    documentation.
  - Add documentation for Device class
  - Add documentation for Region class
- Create a libcairomm-1_0-1 subpackage to follow the shared library
  packaging policy. Add appropriate Provides/Obsoletes.
- Remove explicit cairo-devel and libsigc++2-devel Requires of
  devel package: they will automatically be added the
  pkgconfig()-way.
* Thu Oct 28 2010 vuntz@opensuse.org
- Update to version 1.9.6:
  + Context: Added in_clip().
  + Surface: Added get_mime_data(), set_mime_data(),
    unset_mime_data().
  + Build: Added support for Windows 64-bit and Visual Studio 2010.
* Sat Oct 23 2010 vuntz@opensuse.org
- Update to version 1.9.4:
  + Added Device.
* Mon Sep  6 2010 dimstar@opensuse.org
- Update to version 1.9.2:
  + Context:
  - set_dash(): Make the dashes parameter const.
  - device_to_user(), device_to_user_distance(), user_to_device()
    user_to_device_distance(): Deprecate the non-const versions,
    adding const versions.
  + fdo#28246: Cleanup of most -Weffc++ warnings
* Mon Aug  2 2010 dimstar@opensuse.org
- Update to version 1.9.1:
  + Added Region.
  + Context: Don't allow this to be copied.
  + Fix the MSVC build
  + Fix the 64-bit build.
  + Actually install cairomm-xlib-xrender-1.0.pc
* Thu Jun 10 2010 wittemar@googlemail.com
- build 32bit-package
* Tue Dec  1 2009 vuntz@opensuse.org
- Update to version 1.8.4:
  + move to new mm-common build infrastructure
- Use spec-cleaner on the spec file.
* Sun Jul 19 2009 dominique-obs@leuenberger.net
- Update to version 1.8.2:
  + Fix accidental ABI breakage from 1.8.0
* Tue Feb  3 2009 hfiguiere@suse.de
- Install documentation (bnc#472078)
* Mon Feb  2 2009 mboman@suse.de
- Update to version 1.8.0:
  + No notable changes since 1.7.2
* Fri Dec 26 2008 mboman@suse.de
- Update to version 1.7.2:
  + API Changes (all API changes are in unstable API introduced in 1.7.x)
  + UserFontFace is not implemented with virtual functions rather than by
    registering callbacks
  + Cairo::scaled_matrix() -> Cairo::scaling_matrix() to match other matrix
    convenience functions
  + Incorrect refcounting on ScaledFont
  + build fixes for Mac OSX
* Sun Dec 14 2008 mboman@suse.de
- Update to version 1.7.0:
  + To many changes and fixes to list. See NEWS for full details.
* Tue Sep 23 2008 maw@suse.de
- Update to version 1.6.4:
  + New API:
  * wrap cairo_format_stride_for_width()
  + Fixed a bug where an exception message would often report
    "Success" when it should have reported an error message
  + Added ability to get the error status code from an exception:
    Cairo::logic_error::get_status_code()
  + Added new elements to the surface type enumeration
  + Bugs fixed: bfo#14559 and bfo#14558.
* Tue Jun 17 2008 crrodriguez@suse.de
- disable unusable static libraries
* Mon Mar 31 2008 vuntz@suse.de
- Update to version 1.4.8:
  + Bug fd.o #14559: build failure in exception.cc on Solaris with
    Sun Workshop C++
  + Bug fd.o #14558: cairomm 1.4.6 context.cc needs math.h on
    Solaris
- Changes from version 1.4.6:
  + Bug fd.o #11972: Cannot build cairomm with Quartz enabled
- Changes from version 1.4.4:
  + Added the --enable-api-exceptions=yes/no configure option, to
    allow cairomm to build when exceptions are disabled. For
    instance, when using CXXFLAGS=-fno-exceptions with g++.
- Changes from version 1.4.2:
  + Bug fd.o #11596: Fixed broken shared library versioning
  + Bug fd.o #8511: RefPtr: refcounting broken with cast_*()
    methods
- Changes from version 1.4.0:
  + Wrapped new API added in cairo 1.4
  + Added support for Quartz surfaces
  + ability to use dynamic casting for surfaces and patterns
    returned from Context::get_target(), Context::get_source(),
    etc.
  + Various build and bug fixes
- Changes from version 1.2.4:
  + Fixed an error that prevented Cairo::RefPtr<>::cast_static()
    and Cairo::RefPtr<>::cast_dynamic() from compiling.
- Stop using %%run_ldconfig and run /sbin/ldconfig directly.
* Fri Jan 12 2007 sbrabec@suse.cz
- Spec file cleanup.
* Sun Jan  7 2007 ro@suse.de
- GNOME moved to /usr
* Mon Sep 18 2006 jhargadon@suse.de
- Initial SuSE package version 1.2.2
